@@ -226,8 +226,8 @@ class OLS:
             summ = f"==================================================================================\n"
             summ += f'|                                  OLS summary                                   |\n'
             summ += f"==================================================================================\n"
-            summ += f"| McFadden's R²  =         {_r2:10} | McFadden's R² Adj.  =         {ar2:10} |\n"
-            summ += f"| n              =         {_n_:10} | p                   =         {_p_:10} |\n"
+            summ += f"| R²             =         {_r2:10} | R² Adj.      =                {ar2:10} |\n"
+            summ += f"| n              =         {_n_:10} | p            =                {_p_:10} |\n"
             summ += f"| Fisher value   =    {fis:15} |                                          |\n"
             summ += f"==================================================================================\n"
             summ += summary(summary_df)
